What’s new in version 1.1.2
===========================
Version available since June 22th 2022


Changes
-------
- Only forward-mode for Automatic Differentiation is used to avoid issues with dynamic optimization.


Contributors
------------
Lucas Agobert
